/*
 * @package   ats
 * @copyright Copyright (c)2011-2020 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU General Public License version 3, or later
 */

if (typeof (akeeba) === "undefined")
{
    var akeeba = {};
}

if (typeof (akeeba.ATS) === "undefined")
{
    akeeba.ATS = {};
}

if (typeof (akeeba.ATS.TimeCards) === "undefined")
{
    akeeba.ATS.TimeCards = {
        timeChart: null
    };
}

akeeba.ATS.TimeCards.load = function ()
{
    akeeba.System.doAjax({
        ajaxURL:        Joomla.getOptions("system.paths").base +
                            "/index.php?option=com_ats&view=TimeCards&task=browse&format=json",
        useTripleHash:  false,
        "limitstart":   0,
        "limit":        0,
        "sumtimespent": 1,
        "created_on":   {
            "from":    document.getElementById("time_start").value,
            "to":      document.getElementById("time_end").value,
            "method":  "between",
            "include": true
        }
    }, function (data)
    {
        akeeba.ATS.TimeCards.renderGraph(data);
    });
};

akeeba.ATS.TimeCards.renderGraph = function (data)
{
    var chartOptions = {
        type:    "bar",
        data:    {
            datasets: [
                {
                    label:           "Hours",
                    data:            data.data,
                    backgroundColor: "#40B5B8",
                    fill:            true,
                    yAxisID:         "y-axis-hours"
                }
            ]
        },
        options: {
            legend: {
                display: false
            },
            scales: {
                xAxes: [
                    {
                        type:   "category",
                        labels: data.labels,
                        ticks:  {
                            fontColor: "#F0AD4E"
                        }
                    }
                ],
                yAxes: [
                    {
                        id:       "y-axis-hours",
                        position: "left",
                        ticks:    {
                            fontColor:   "#40B5B8",
                            beginAtZero: true
                        }
                    }
                ]
            }
        }
    };

    if (akeeba.ats.timecards.timeChart)
    {
        akeeba.ats.timecards.timeChart.destroy();
        akeeba.ats.timecards.timeChart = null;
    }

    akeeba.ats.timecards.timeChart = new Chart(document.getElementById("ats-timecard"), chartOptions);
};

akeeba.System.documentReady(function ()
{
    akeeba.System.addEventListener("time_graph_reload", "click", akeeba.ATS.TimeCards.load);

    akeeba.ATS.TimeCards.load();
});